EXPORTS
	??0T_LbsUtils@@QAE@XZ @ 1 NONAME ; T_LbsUtils::T_LbsUtils(void)
	??1CT_LbsTimerUtils@@UAE@XZ @ 2 NONAME ; CT_LbsTimerUtils::~CT_LbsTimerUtils(void)
	??1T_LbsUtils@@QAE@XZ @ 3 NONAME ; T_LbsUtils::~T_LbsUtils(void)
	?CancelTimer@CT_LbsTimerUtils@@QAEXXZ @ 4 NONAME ; void CT_LbsTimerUtils::CancelTimer(void)
	?Compare_ModuleInfo@T_LbsUtils@@QAEHAAVTPositionModuleInfo@@0@Z @ 5 NONAME ; int T_LbsUtils::Compare_ModuleInfo(class TPositionModuleInfo &, class TPositionModuleInfo &)
	?Compare_ModuleStatus@T_LbsUtils@@QAEHAAVTPositionModuleStatus@@0@Z @ 6 NONAME ; int T_LbsUtils::Compare_ModuleStatus(class TPositionModuleStatus &, class TPositionModuleStatus &)
	?Compare_ModuleUpdateOptions@@YAHAAVTPositionUpdateOptions@@0@Z @ 7 NONAME ; int Compare_ModuleUpdateOptions(class TPositionUpdateOptions &, class TPositionUpdateOptions &)
	?Compare_PosInfo@T_LbsUtils@@QAEHABVTPositionInfoBase@@0@Z @ 8 NONAME ; int T_LbsUtils::Compare_PosInfo(class TPositionInfoBase const &, class TPositionInfoBase const &)
	?Compare_PosInfo@T_LbsUtils@@QAEHABVTPositionInfoBase@@0W4TComparisonAccuracyType@1@@Z @ 9 NONAME ; int T_LbsUtils::Compare_PosInfo(class TPositionInfoBase const &, class TPositionInfoBase const &, enum T_LbsUtils::TComparisonAccuracyType)
	?Compare_PosInfoArr@T_LbsUtils@@QAEHAAV?$RPointerArray@X@@0@Z @ 10 NONAME ; int T_LbsUtils::Compare_PosInfoArr(class RPointerArray<void> &, class RPointerArray<void> &)
	?Compare_PosInfoArr@T_LbsUtils@@QAEHAAV?$RPointerArray@X@@0W4TComparisonAccuracyType@1@@Z @ 11 NONAME ; int T_LbsUtils::Compare_PosInfoArr(class RPointerArray<void> &, class RPointerArray<void> &, enum T_LbsUtils::TComparisonAccuracyType)
	?Compare_PositionQuality@T_LbsUtils@@QAEHAAVTPositionQuality@@0@Z @ 12 NONAME ; int T_LbsUtils::Compare_PositionQuality(class TPositionQuality &, class TPositionQuality &)
	?CreateTestPropertiesL@T_LbsUtils@@QAEXXZ @ 13 NONAME ; void T_LbsUtils::CreateTestPropertiesL(void)
	?Create_ModuleInfoL@T_LbsUtils@@QAEXVTUid@@AAVTPositionModuleInfo@@@Z @ 14 NONAME ; void T_LbsUtils::Create_ModuleInfoL(class TUid, class TPositionModuleInfo &)
	?GetAGpsModuleIdL@T_LbsUtils@@QAE?AVTUid@@AAVRPositionServer@@@Z @ 15 NONAME ; class TUid T_LbsUtils::GetAGpsModuleIdL(class RPositionServer &)
	?GetBadModuleId@T_LbsUtils@@QAE?AVTUid@@XZ @ 16 NONAME ; class TUid T_LbsUtils::GetBadModuleId(void)
	?GetConfigured_ModuleStatusL@T_LbsUtils@@QAEXABVTDesC16@@0AAVTPositionModuleStatus@@@Z @ 17 NONAME ; void T_LbsUtils::GetConfigured_ModuleStatusL(class TDesC16 const &, class TDesC16 const &, class TPositionModuleStatus &)
	?GetConfigured_ModuleUpdateOptionsL@T_LbsUtils@@QAEXABVTDesC16@@0AAVTPositionUpdateOptions@@@Z @ 18 NONAME ; void T_LbsUtils::GetConfigured_ModuleUpdateOptionsL(class TDesC16 const &, class TDesC16 const &, class TPositionUpdateOptions &)
	?GetConfigured_PosInfosL@T_LbsUtils@@QAEXABVTDesC16@@0AAV?$RPointerArray@X@@@Z @ 19 NONAME ; void T_LbsUtils::GetConfigured_PosInfosL(class TDesC16 const &, class TDesC16 const &, class RPointerArray<void> &)
	?GetNetworkModuleIdL@T_LbsUtils@@QAE?AVTUid@@AAVRPositionServer@@@Z @ 20 NONAME ; class TUid T_LbsUtils::GetNetworkModuleIdL(class RPositionServer &)
	?NewL@CT_LbsAsyncWaiter@@SAPAV1@XZ @ 21 NONAME ; class CT_LbsAsyncWaiter * CT_LbsAsyncWaiter::NewL(void)
	?NewL@CT_LbsTimerUtils@@SAPAV1@PAVMT_LbsTimerUtilsObserver@@H@Z @ 22 NONAME ; class CT_LbsTimerUtils * CT_LbsTimerUtils::NewL(class MT_LbsTimerUtilsObserver *, int)
	?NotifyModuleOfConfigChangeL@T_LbsUtils@@QAEXABVTModuleDataIn@@@Z @ 23 NONAME ; void T_LbsUtils::NotifyModuleOfConfigChangeL(class TModuleDataIn const &)
	?ResetAndDestroy_PosInfoArr@T_LbsUtils@@QAEXAAV?$RPointerArray@X@@@Z @ 24 NONAME ; void T_LbsUtils::ResetAndDestroy_PosInfoArr(class RPointerArray<void> &)
	?Result@CT_LbsAsyncWaiter@@QBEHXZ @ 25 NONAME ; int CT_LbsAsyncWaiter::Result(void) const
	?SetTimer@CT_LbsTimerUtils@@QAEXABVTTime@@@Z @ 26 NONAME ; void CT_LbsTimerUtils::SetTimer(class TTime const &)
	?SetTimer@CT_LbsTimerUtils@@QAEXVTTimeIntervalMicroSeconds32@@@Z @ 27 NONAME ; void CT_LbsTimerUtils::SetTimer(class TTimeIntervalMicroSeconds32)
	?StartAndWait@CT_LbsAsyncWaiter@@QAEXXZ @ 28 NONAME ; void CT_LbsAsyncWaiter::StartAndWait(void)
	?VerifySimpleAssistanceData@T_LbsUtils@@QAEHAAVRUEPositioningGpsReferenceTimeReader@@@Z @ 29 NONAME ; int T_LbsUtils::VerifySimpleAssistanceData(class RUEPositioningGpsReferenceTimeReader &)
	?Verify_PositionIsValid@T_LbsUtils@@QAEHAAVTPositionInfo@@@Z @ 30 NONAME ; int T_LbsUtils::Verify_PositionIsValid(class TPositionInfo &)
	?WaitForModuleToRequestAssistanceDataL@T_LbsUtils@@QAEXXZ @ 31 NONAME ; void T_LbsUtils::WaitForModuleToRequestAssistanceDataL(void)
	?Compare_AssistanceDataLog@T_LbsUtils@@QAEHABVCLbsAssistanceDataLogEvent@@0@Z @ 32 NONAME ; int T_LbsUtils::Compare_AssistanceDataLog(class CLbsAssistanceDataLogEvent const &, class CLbsAssistanceDataLogEvent const &)
	?Compare_ExternalLocateLog@T_LbsUtils@@QAEHABVCLbsExternalLocateLogEvent@@0@Z @ 33 NONAME ; int T_LbsUtils::Compare_ExternalLocateLog(class CLbsExternalLocateLogEvent const &, class CLbsExternalLocateLogEvent const &)
	?Compare_LogBase@T_LbsUtils@@QAEHABVCLbsLogEvent@@0@Z @ 34 NONAME ; int T_LbsUtils::Compare_LogBase(class CLbsLogEvent const &, class CLbsLogEvent const &)
	?Compare_NetworkLocateLog@T_LbsUtils@@QAEHABVCLbsNetworkLocateLogEvent@@0@Z @ 35 NONAME ; int T_LbsUtils::Compare_NetworkLocateLog(class CLbsNetworkLocateLogEvent const &, class CLbsNetworkLocateLogEvent const &)
	?Compare_SelfLocateLog@T_LbsUtils@@QAEHABVCLbsSelfLocateLogEvent@@0@Z @ 36 NONAME ; int T_LbsUtils::Compare_SelfLocateLog(class CLbsSelfLocateLogEvent const &, class CLbsSelfLocateLogEvent const &)
	?Compare_TransmitLocationLog@T_LbsUtils@@QAEHABVCLbsTransmitLocationLogEvent@@0@Z @ 37 NONAME ; int T_LbsUtils::Compare_TransmitLocationLog(class CLbsTransmitLocationLogEvent const &, class CLbsTransmitLocationLogEvent const &)
	??0TLbsModuleUpdateItem@@QAE@XZ @ 38 NONAME ; TLbsModuleUpdateItem::TLbsModuleUpdateItem(void)
	?Error@TLbsModuleUpdateItem@@QBEHXZ @ 39 NONAME ; int TLbsModuleUpdateItem::Error(void) const
	?Measurement@TLbsModuleUpdateItem@@QBEABVTPositionGpsMeasurementInfo@@XZ @ 40 NONAME ; class TPositionGpsMeasurementInfo const & TLbsModuleUpdateItem::Measurement(void) const
	?Position@TLbsModuleUpdateItem@@QBEABVTPositionSatelliteInfo@@XZ @ 41 NONAME ; class TPositionSatelliteInfo const & TLbsModuleUpdateItem::Position(void) const
	?SetError@TLbsModuleUpdateItem@@QAEXH@Z @ 42 NONAME ; void TLbsModuleUpdateItem::SetError(int)
	?SetMeasurement@TLbsModuleUpdateItem@@QAEXABVTPositionGpsMeasurementInfo@@@Z @ 43 NONAME ; void TLbsModuleUpdateItem::SetMeasurement(class TPositionGpsMeasurementInfo const &)
	?SetPosition@TLbsModuleUpdateItem@@QAEXABVTPositionSatelliteInfo@@@Z @ 44 NONAME ; void TLbsModuleUpdateItem::SetPosition(class TPositionSatelliteInfo const &)
	?Write@CT_Dumper@@SAXV?$TRefByValue@$$CBVTDesC16@@@@ZZ @ 45 NONAME ; void CT_Dumper::Write(class TRefByValue<class TDesC16 const >, ...)
	?OverWrite@CT_Dumper@@SAXXZ @ 46 NONAME ; void CT_Dumper::OverWrite(void)
	?GetConfigured_UpdateArrayL@T_LbsUtils@@QAEXABVTDesC16@@0AAV?$RPointerArray@VTLbsModuleUpdateItem@@@@@Z @ 47 NONAME ; void T_LbsUtils::GetConfigured_UpdateArrayL(class TDesC16 const &, class TDesC16 const &, class RPointerArray<class TLbsModuleUpdateItem> &)
	?NewL@CT_LbsAGpsHandler@@SAPAV1@PAVMT_ResponseObserver@@@Z @ 48 NONAME ; class CT_LbsAGpsHandler * CT_LbsAGpsHandler::NewL(class MT_ResponseObserver *)
	?SendRequestClearAllModuleOptions@CT_LbsAGpsHandler@@QAEXXZ @ 49 NONAME ; void CT_LbsAGpsHandler::SendRequestClearAllModuleOptions(void)
	?SendRequestError@CT_LbsAGpsHandler@@QAEXH@Z @ 50 NONAME ; void CT_LbsAGpsHandler::SendRequestError(int)
	?SendRequestModuleOption@CT_LbsAGpsHandler@@QAEXW4TLbsHybridModuleOptions@@H@Z @ 51 NONAME ; void CT_LbsAGpsHandler::SendRequestModuleOption(enum TLbsHybridModuleOptions, int)
	?SendRequestSetAllModuleOptions@CT_LbsAGpsHandler@@QAEXXZ @ 52 NONAME ; void CT_LbsAGpsHandler::SendRequestSetAllModuleOptions(void)
	?SendRequestTimeOutMsg@CT_LbsAGpsHandler@@QAEXABVTTimeIntervalMicroSeconds@@@Z @ 53 NONAME ; void CT_LbsAGpsHandler::SendRequestTimeOutMsg(class TTimeIntervalMicroSeconds const &)
	?SendRequestUpdateInitMsg@CT_LbsAGpsHandler@@QAEXABVTDesC16@@0@Z @ 54 NONAME ; void CT_LbsAGpsHandler::SendRequestUpdateInitMsg(class TDesC16 const &, class TDesC16 const &)
	?Delay@TLbsModuleUpdateItem@@QBEHXZ @ 55 NONAME ; int TLbsModuleUpdateItem::Delay(void) const
	?SetDelay@TLbsModuleUpdateItem@@QAEXH@Z @ 56 NONAME ; void TLbsModuleUpdateItem::SetDelay(int)
	??1CT_AgpsModuleEventListener@@UAE@XZ @ 57 NONAME ; CT_AgpsModuleEventListener::~CT_AgpsModuleEventListener(void)
	?GetExpected_ModuleModes@T_LbsUtils@@QAEXABVTDesC16@@0AAV?$RPointerArray@VTLbsGpsOptions@@@@@Z @ 58 NONAME ; void T_LbsUtils::GetExpected_ModuleModes(class TDesC16 const &, class TDesC16 const &, class RPointerArray<class TLbsGpsOptions> &)
	?NewL@CT_AgpsModuleEventListener@@SAPAV1@AAVMT_AgpsModuleEventHandler@@@Z @ 59 NONAME ; class CT_AgpsModuleEventListener * CT_AgpsModuleEventListener::NewL(class MT_AgpsModuleEventHandler &)
	?GetConfigured_ClientDetailsL@T_LbsUtils@@QAEXABVTDesC16@@0AAV?$RArray@VTCTClientDetails@@@@@Z @ 60 NONAME ; void T_LbsUtils::GetConfigured_ClientDetailsL(class TDesC16 const &, class TDesC16 const &, class RArray<class TCTClientDetails> &)
	?SendRequestForcedUpdate@CT_LbsAGpsHandler@@QAEXXZ @ 61 NONAME ; void CT_LbsAGpsHandler::SendRequestForcedUpdate(void)

